//model without pie_oil, equations (random walk) for r_gap, z_gap, pie_m; similar to Laxton

var gamma y_pot y_gap u_gap NAIRU y u pie r_gap z_gap pie_m;


varexo  gamma_ss e_y_pot e_y_gap e_gamma e_NAIRU e_u_gap e_pie e_r_gap e_z_gap e_pie_m;


parameters a1 a2 a3 m1 b1 b2 c1 c2 c4 c5 r1 z1 p1;


a1     = 0.6;
a2     = 0.2;
a3     = 0.1;
m1     = 0.7;
b1     = 0.2;
b2     = 0.8;
c1 = 0.2;
c2 = 0.2;
c4 = 0.5;
c5 = 0.5;
r1 = 0.8;
z1 = 0.8;
p1 = 0.8;


model(linear); 

//Stochastic process for output gap
 gamma = m1*gamma_ss+(1-m1)*gamma(-1)+e_gamma;
 y_pot = gamma+y_pot(-1)+e_y_pot;


//Outpu gap dynamics
    //y_gap = a1*y_gap(-1)-a2*r_gap-a3*z_gap+e_y_gap;
 y_gap = a1*y_gap(-1)-a2*r_gap(-1)+a3*z_gap(-1)+e_y_gap;

//Unemployment gap - Okun's law
 u_gap = -b1*y_gap+b2*u_gap(-1)+e_u_gap;

//Inflation Equation - Phillips curve
 pie = c1*pie_m+c2*pie(+4)+(1-c1-c2)*pie(-1)-c4*u_gap-c5*(u_gap-u_gap(-1))+e_pie;
 
//Definition - NAIRU, Output gap
 NAIRU = NAIRU(-1)+e_NAIRU;
 100*y = 100*y_pot+y_gap;
 u = NAIRU +u_gap;

//Stochastic process - r,z,pie_m
 r_gap = r1*r_gap(-1)+e_r_gap;
 z_gap = z1*z_gap(-1)+e_z_gap;
 pie_m = p1*pie_m(-1)+e_pie_m;



end;

initval;
gamma_ss = 0;
gamma = 0;//0.008;
y_pot = gamma+9.9;


z_gap = 0;
r_gap = 0;

y_gap = 1/(1-a1)*(-a2*r_gap+a3*z_gap);
y = y_gap+y_pot;
NAIRU = 3.5;
u_gap = 1/(1-b2)*(-b1*y_gap);
u = u_gap+NAIRU;
pie_m = 0;
pie = 1/c1*(c1*pie_m-c4*u_gap);
e_y_pot = 0;
e_y_gap = 0;
e_u_gap = 0;
e_NAIRU = 0;
e_gamma = 0;
e_pie=0;
e_r_gap=0;
e_z_gap=0;
e_pie_m=0;
end;

shocks;
var e_y_gap=0.3;
var e_y_pot=0.3;
var e_gamma=0.1;
var e_NAIRU=0.3;
var e_u_gap=0.3;
var e_pie = 0.1;
var e_r_gap=0.2;
var e_z_gap=0.5;
var e_pie_m = 0.1;
end;

steady;
check;

estimated_params;
a1, beta_pdf,   0.7, 0.1;
a2, beta_pdf,   0.2,  0.1;
a3, beta_pdf, 0.2, 0.1;
m1, beta_pdf, 0.2,   0.1;
b1, beta_pdf,   0.3, 0.1;
b2,   beta_pdf, 0.8, 0.1;
c1,   beta_pdf, 0.2, 0.1;
c2,   beta_pdf, 0.2, 0.1;
c4,   normal_pdf, 0.5, 0.3;

c5,   normal_pdf, 0.5, 0.3;

r1, beta_pdf,   0.8, 0.1;//0.1,  0.05;
z1, beta_pdf,   0.8, 0.1;//0.1,  0.05;
p1, beta_pdf,   0.8, 0.1;//0.1,  0.05;

stderr e_y_gap, inv_gamma_pdf, 0.1, 30;
stderr e_y_pot, inv_gamma_pdf, 0.2, 30;
stderr e_gamma, inv_gamma_pdf, 0.1, 30;
stderr e_NAIRU, inv_gamma_pdf, 0.2, 30;
stderr e_u_gap, inv_gamma_pdf, 0.2, 30;
stderr e_pie, inv_gamma_pdf, 0.4, 30;
stderr e_r_gap, inv_gamma_pdf, 1, 30;
stderr e_z_gap, inv_gamma_pdf, 3, 30;
stderr e_pie_m, inv_gamma_pdf, 2, 30;
end;


varobs y u pie r_gap z_gap pie_m;


unit_root_vars NAIRU y_pot; //r_gap z_gap pie_m;

//stoch_simul;

estimation(datafile=laxton_data, mode_compute=4, mh_replic=100000,mh_jscale=0.48, presample=4, lik_init=1, mh_drop =0.5, mode_check, forecast=5);