//model without pie_oil, equations (random walk) for r_gap, z_gap, pie_m; similar to Laxton

var gamma y_pot y_gap u_gap NAIRU y u pie r_gap z_gap pie_m;

varexo  gamma_ss e_y_pot e_y_gap e_gamma e_NAIRU e_u_gap e_pie e_r_gap e_z_gap e_pie_m;

parameters a1 a2 a3 m1 b1 b2 c1 c2 c3 c4 c5 r1 z1 p1;

a1     = 0.6493;
a2     = 0.2074;
a3     = 0.0194;
m1     = 0.3184;
b1     = 0.2851;
b2     = 0.7607;
c1 = 0.0214;
c2 = 0.0874;
c4 = 0.5769;
c5 = 0.6106;
r1 = 0.7639;
z1 = 0.8382;
p1 = 0.9066;



model; 

//Stochastic process for output gap
 gamma = m1*gamma_ss+(1-m1)*gamma(-1)+e_gamma;
 y_pot = gamma+y_pot(-1)+e_y_pot;

//Outpu gap dynamics
    //y_gap = a1*y_gap(-1)-a2*r_gap-a3*z_gap+e_y_gap;
 y_gap = a1*y_gap(-1)-a2*r_gap(-1)-a3*z_gap(-1)+e_y_gap;

//Unemployment gap - Okun's law
 u_gap = -b1*y_gap+b2*u_gap(-1)+e_u_gap;

//Inflation Equation - Phillips curve
 pie = c1*pie_m+c2*pie(+4)+(1-c1-c2)*pie(-1)-c4*u_gap-c5*(u_gap-u_gap(-1))+e_pie;
 
//Definition - NAIRU, Output gap
 NAIRU = NAIRU(-1)+e_NAIRU;
 100*y = 100*y_pot+y_gap;
 u = NAIRU +u_gap;

//Stochastic process - r,z,pie_m
 r_gap = r1*r_gap(-1)+e_r_gap;
 z_gap = z1*z_gap(-1)+e_z_gap;
 pie_m = p1*pie_m(-1)+e_pie_m;
end;


initval;
gamma_ss = 0;
gamma = 0;
y_pot = gamma+9.9;
y_pot = 9.9;

z_gap = 0;
r_gap = 0;

y_gap = 1/(1-a1)*(-a2*r_gap-a3*z_gap);
y = y_gap+y_pot;
NAIRU = 3.5;
u_gap = 1/(1-b2)*(-b1*y_gap);
u = u_gap+NAIRU;
pie_m = 0;
pie = 1/c1*(c1*pie_m-c4*u_gap);
e_y_pot = 0;
e_y_gap = 0;
e_u_gap = 0;
e_NAIRU = 0;
e_gamma = 0;
e_pie=0;
e_r_gap=0;
e_z_gap=0;
e_pie_m=0;
end;

steady;

shocks;
 var e_y_gap; stderr 0.2780;
 var e_y_pot; stderr 0.0235;
 var e_gamma; stderr 0.0138;
 var e_NAIRU; stderr 0.1926;
 var e_u_gap; stderr 0.0417;
 var   e_pie; stderr 0.0652;
 var e_r_gap; stderr 0.6314;
 var e_z_gap; stderr 2.8826;
 var e_pie_m; stderr 1.7495;
end;



stoch_simul(ar=10, drop=200, irf=50, periods=4000, simul) gamma y_pot y_gap u_gap NAIRU y u pie r_gap z_gap pie_m;
check;
