function [x, y, S] = kalman(z, A, B, C, Rw, Re, x0, S0);

% [x, y] = kalman(z, A, B, C, Rw, Re, x0, S0);
%
%
% Linear state-space model of the form
% x(t+1) = A x(t) + B u(t) + w(t)
%   y(t) = C x(t) + e(t)
%
% var w(t) = Rw
% var e(t) = Re
% var y(t) = Ry
%
% x(t|t-1) ~ N{ est x(t|t-1), S(t|t-1) }
%   x(t|t) ~ N{ est x(t|t), S(t|t) }
%
% Initial condition
% x(1|0) = x0
% S(1|0) = S0

[na, ka] = size(A);
[nb, kb] = size(B);
[nc, kc] = size(C);
[nz, kz] = size(z);
[nx0, kx0] = size(x0);
[nS0, kS0] = size(S0);
if ~( na==ka & na==nb & na==kc & (nc+kb==kz) & nS0==kS0 & nS0==na & nx0==na & kx0 ==1),
  error('Incorrect size of some matrix.');
end,

y.act = z(:, 1:nc); u = z(:, nc+1:end);
S.pre{1} = S0;
x.pre = x0';

% Forward run

for i = 1 : nz
  
  % Prediction (model step)
  if (i > 1),
    x.pre(i, :) = ( A*x.fil(i-1, :)' + B*u(i, :)' )';
    S.pre{i}    = Rw + A * S.fil{i-1} * A';
  end,
  y.pre(i, :) = ( C*x.pre(i, :)' )';
  Ry.pre = Re + C * S.pre{i} * C';

  % Filtering (data step)
  S.fil{i}    = S.pre{i} - S.pre{i} * C' * inv(Ry.pre) * C * S.pre{i};
  x.fil(i, :) = x.pre(i, :) + ( S.fil{i} * C' * inv(Re) * (y.act(i, :)' - y.pre(i, :)') )';
  
end,

% Smoothing

x.smo(nz, :) = x.fil(end, :);
S.smo{nz}    = S.fil{nz};

for i = nz-1 : -1: 1
  
  F = S.fil{i} * A' * inv(S.pre{i+1});
  x.smo(i, :) = x.fil(i, :) + ( F*(x.smo(i+1, :)'-x.pre(i+1, :)') )';
  S.smo{i} = S.fil{i} - F*(S.pre{i+1}-S.smo{i+1})*F';
  
end